;;; site-gentoo.el --- site initialisation for Gentoo-installed packages

;;; Commentary:
;; Automatically generated by elisp-common.eclass
;; DO NOT EDIT THIS FILE

;;; Code:

;;; emacs-daemon site-lisp configuration

;; Copyright 2008-2016 Gentoo Foundation
;; Distributed under the terms of the GNU General Public License v2 or later

(and
 (fboundp 'daemonp)
 (daemonp)
 (null after-init-time)
 (let* ((file (concat "/var/run/emacs/" (user-login-name) "/emacs.pid"))
	(pid (if (file-readable-p file)
		 ;; Get process id from file
		 (with-temp-buffer
		   (ignore-errors
		    (insert-file-contents-literally file nil 0 100)
		    (and (looking-at "[0-9]+")
			 (string-to-number (match-string 0))))))))
   (cond
    ((and (integerp pid)
	  (string-match
	   "emacs" (or (cdr (assq 'comm (process-attributes pid))) ""))
	  (/= pid (emacs-pid)))
     ;; If another Emacs daemon is already running for this user,
     ;; then we would steal its server socket. So we better die.
     (message "Another Emacs daemon is already running at process id %d" pid)
     (kill-emacs))
    ((file-writable-p file)
     ;; Write process id to file
     (with-temp-file file
       (insert (number-to-string (emacs-pid)) "\n"))
     ;; Remove file on exit
     (add-hook 'kill-emacs-hook
	       `(lambda () (ignore-errors (delete-file ,file))))))
   ;; Restart the server if signal SIGUSR1 is received.
   (define-key special-event-map [sigusr1] 'server-start)))

;;; emacs-23 site-lisp configuration

(when (string-match "\\`23\\.4\\>" emacs-version)
  (let ((path (getenv "INFOPATH"))
	(dir "/usr/share/info/emacs-23")
	(re "\\`/usr/share/info\\>"))
    (and path
	 ;; move Emacs Info dir before anything else in /usr/share/info
	 (let* ((p (cons nil (split-string path ":" t))) (q p))
	   (while (and (cdr q) (not (string-match re (cadr q))))
	     (setq q (cdr q)))
	   (setcdr q (cons dir (delete dir (cdr q))))
	   (setq Info-directory-list (prune-directory-list (cdr p)))))))

;;; emacs-24 site-lisp configuration

(when (string-match "\\`24\\.5\\>" emacs-version)
  (let ((path (getenv "INFOPATH"))
	(dir "/usr/share/info/emacs-24")
	(re "\\`/usr/share/info\\>"))
    (and path
	 ;; move Emacs Info dir before anything else in /usr/share/info
	 (let* ((p (cons nil (split-string path ":" t))) (q p))
	   (while (and (cdr q) (not (string-match re (cadr q))))
	     (setq q (cdr q)))
	   (setcdr q (cons dir (delete dir (cdr q))))
	   (setq Info-directory-list (prune-directory-list (cdr p)))))))

;;; emacs-vcs-25 site-lisp configuration

(when (string-match "\\`25\\.0\\.95\\>" emacs-version)
  (let ((path (getenv "INFOPATH"))
	(dir "/usr/share/info/emacs-25-vcs")
	(re "\\`/usr/share/info\\>"))
    (and path
	 ;; move Emacs Info dir before anything else in /usr/share/info
	 (let* ((p (cons nil (split-string path ":" t))) (q p))
	   (while (and (cdr q) (not (string-match re (cadr q))))
	     (setq q (cdr q)))
	   (setcdr q (cons dir (delete dir (cdr q))))
	   (setq Info-directory-list (prune-directory-list (cdr p)))))))

;;; apel site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/apel")

;;; auctex site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/auctex")
(require 'tex-site)

;; detect needed steps after rebuild
(setq TeX-parse-self t)

;;; autoconf-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/autoconf-mode")
(autoload 'autoconf-mode "autoconf-mode"
  "Major mode for editing autoconf files." t)
(autoload 'autotest-mode "autotest-mode"
  "Major mode for editing autotest files." t)
(add-to-list 'auto-mode-alist
	     '("\\.ac\\'\\|configure\\.in\\'" . autoconf-mode))
(add-to-list 'auto-mode-alist
	     '("\\.at\\'" . autotest-mode))

;;; color-theme site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/color-theme")

(autoload (quote color-theme-select) "color-theme" "\
Displays a special buffer for selecting and installing a color theme.
With optional prefix ARG, this buffer will include color theme libraries
as well.  A color theme library is in itself not complete, it must be
used as part of another color theme to be useful.  Thus, color theme
libraries are mainly useful for color theme authors." t nil)

(autoload (quote color-theme-describe) "color-theme" "\
Describe color theme listed at point.
This shows the documentation of the value of text-property color-theme
at point.  The text-property color-theme should be a color theme
function.  See `color-themes'." t nil)

(autoload (quote color-theme-install-at-mouse) "color-theme" "\
Install color theme clicked upon using the mouse.
First argument EVENT is used to set point.  Then
`color-theme-install-at-point' is called." t nil)

(autoload (quote color-theme-install-at-point-for-current-frame) "color-theme" "\
Install color theme at point for current frame only.
Binds `color-theme-is-global' to nil and calls
`color-theme-install-at-point'." t nil)

(autoload (quote color-theme-print) "color-theme" "\
Print the current color theme function.

You can contribute this function to <URL:news:gnu.emacs.sources> or
paste it into your .emacs file and call it.  That should recreate all
the settings necessary for your color theme.

Example:

    (require 'color-theme)
    (defun my-color-theme ()
      \"Color theme by Alex Schroeder, created 2000-05-17.\"
      (interactive)
      (color-theme-install
       '(...
	 ...
	 ...)))
    (my-color-theme)

If you want to use a specific color theme function, you can call the
color theme function in your .emacs directly.

Example:

    (require 'color-theme)
    (color-theme-gnome2)" t nil)

(autoload (quote color-theme-analyze-defun) "color-theme" "\
Once you have a color-theme printed, check for missing faces.
This is used by maintainers who receive a color-theme submission
and want to make sure it follows the guidelines by the color-theme
author." t nil)

(autoload (quote color-theme-make-snapshot) "color-theme" "\
Return the definition of the current color-theme.
The function returned will recreate the color-theme in use at the moment." nil nil)

(autoload (quote color-theme-compare) "color-theme" "\
Compare two color themes.
This will print the differences between installing THEME-A and
installing THEME-B.  Note that the order is important: If a face is
defined in THEME-A and not in THEME-B, then this will not show up as a
difference, because there is no reset before installing THEME-B.  If a
face is defined in THEME-B and not in THEME-A, then this will show up as
a difference." t nil)

(autoload (quote color-theme-install) "color-theme" "\
Install a color theme defined by frame parameters, variables and faces.

The theme is installed for all present and future frames; any missing
faces are created.  See `color-theme-install-faces'.

THEME is a color theme definition.  See below for more information.

If you want to install a color theme from your .emacs, use the output
generated by `color-theme-print'.  This produces color theme function
which you can copy to your .emacs.

A color theme definition is a list:
\([FUNCTION] FRAME-PARAMETERS VARIABLE-SETTINGS FACE-DEFINITIONS)

FUNCTION is the color theme function which called `color-theme-install'.
This is no longer used.  There was a time when this package supported
automatic factoring of color themes.  This has been abandoned.

FRAME-PARAMETERS is an alist of frame parameters.  These are installed
with `color-theme-install-frame-params'.  These are installed last such
that any changes to the default face can be changed by the frame
parameters.

VARIABLE-DEFINITIONS is an alist of variable settings.  These are
installed with `color-theme-install-variables'.

FACE-DEFINITIONS is an alist of face definitions.  These are installed
with `color-theme-install-faces'.

If `color-theme-is-cumulative' is nil, a color theme will undo face and
frame-parameter settings of previous color themes." nil nil)

(autoload (quote color-theme-submit) "color-theme" "\
Submit your color-theme to the maintainer." t nil)

(autoload (quote color-theme-initialize) "color-theme" "\
Initialize the color theme package by loading color-theme-libraries." t nil)

;;; ebuild-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/ebuild-mode")
(autoload 'ebuild-mode "ebuild-mode"
  "Major mode for Portage .ebuild and .eclass files." t)
(autoload 'gentoo-newsitem-mode "gentoo-newsitem-mode"
  "Major mode for Gentoo GLEP 42 news items." t)

(add-to-list 'auto-mode-alist '("\\.\\(ebuild\\|eclass\\)\\'" . ebuild-mode))
(add-to-list 'auto-mode-alist
	     '("/[0-9]\\{4\\}-[01][0-9]-[0-3][0-9]-.+\\.[a-z]\\{2\\}\\.txt\\'"
	       . gentoo-newsitem-mode))
(add-to-list 'interpreter-mode-alist '("openrc-run" . sh-mode))
(add-to-list 'interpreter-mode-alist '("runscript" . sh-mode))
(modify-coding-system-alist 'file "\\.\\(ebuild\\|eclass\\)\\'" 'utf-8)

;;; eselect-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/eselect-mode")
(autoload 'eselect-mode "eselect-mode" "Major mode for .eselect files." t)
(add-to-list 'auto-mode-alist '("\\.eselect\\'" . eselect-mode))

;;; ess site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/ess")
(require 'ess-site)

;;; gnuplot-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/gnuplot-mode")
;; extracted from dotemacs file distributed with the source tarball
(autoload 'gnuplot-mode "gnuplot" "gnuplot major mode" t)
(autoload 'gnuplot-make-buffer "gnuplot" "open a buffer in gnuplot mode" t)
(add-to-list 'auto-mode-alist '("\\.gp\\'" . gnuplot-mode))
;;(global-set-key [(f9)] 'gnuplot-make-buffer)

;;; lua-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/lua-mode")
(autoload 'lua-mode "lua-mode" "Mode for editing Lua scripts" t)
(add-to-list 'auto-mode-alist '("\\.lua\\'" . lua-mode))
(setq lua-default-application "/usr/bin/lua")

;;; ocaml-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/ocaml-mode")
(add-to-list 'auto-mode-alist '("\\.ml[iylp]?\\'" . caml-mode))
(autoload 'caml-mode "caml" "Major mode for editing Caml code." t)
(autoload 'run-caml "inf-caml" "Run an inferior Caml process." t)
(autoload 'camldebug "camldebug"
  "Run camldebug on program FILE in buffer *camldebug-FILE*." t)
(autoload 'inferior-caml-set-font-lock "caml-font")

(eval-after-load "caml" '(require 'caml-font))
(add-hook 'inferior-caml-mode-hooks 'inferior-caml-set-font-lock)

;;; po-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/po-mode")
(autoload 'po-mode "po-mode" "Major mode for translators to edit PO files" t)
(or (fboundp 'po-find-file-coding-system)
    (autoload 'po-find-file-coding-system "po-compat"))

(add-to-list 'auto-mode-alist '("\\.po\\'\\|\\.po\\." . po-mode))
(modify-coding-system-alist 'file "\\.po\\'\\|\\.po\\."
			    'po-find-file-coding-system)

;;; pymacs site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/pymacs")
(autoload 'pymacs-load "pymacs" nil t)
(autoload 'pymacs-eval "pymacs" nil t)
(autoload 'pymacs-apply "pymacs")
(autoload 'pymacs-call "pymacs")

;;; python-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/python-mode")

(autoload 'python-mode "python-mode" "Major mode for editing Python files." t)
(autoload 'jython-mode "python-mode" "Major mode for editing Jython files." t)
(autoload 'py-shell "python-mode"
  "Start an interactive Python interpreter in another window." t)

(add-to-list 'auto-mode-alist '("\\.py$" . python-mode))
(add-to-list 'auto-mode-alist '("\\.pyx$" . python-mode))
(add-to-list 'interpreter-mode-alist '("python" . python-mode))
(add-to-list 'interpreter-mode-alist '("jython" . jython-mode))

;;; quilt-el site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/quilt-el")
(autoload 'quilt-mode "quilt"
  "Toggle quilt-mode. With positive arg, enable quilt-mode." t)
(autoload 'quilt-hook "quilt"
  "Enable quilt mode for quilt-controlled files.")
(add-hook 'find-file-hooks 'quilt-hook)
(add-hook 'after-revert-hook 'quilt-hook)

;;; ruby-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/ruby-mode")

(autoload 'ruby-mode "ruby-mode" "Major mode to edit ruby files." t)

(add-to-list 'auto-mode-alist '("Rakefile\\'" . ruby-mode))
(add-to-list 'auto-mode-alist '("\\.\\(rake\\|rb\\)\\'" . ruby-mode))
(add-to-list 'interpreter-mode-alist  '("ruby" . ruby-mode))

(autoload 'run-ruby "inf-ruby" "Run an inferior Ruby process" t)
(autoload 'inf-ruby-keys "inf-ruby" "Set local key defs for inf-ruby in ruby-mode")

(add-hook 'ruby-mode-hook 'inf-ruby-keys)

;;; doctest-mode site-lisp configuration

(add-to-list 'load-path "/usr/share/emacs/site-lisp/doctest-mode")
(autoload 'doctest-mode "doctest-mode"
  "Editing mode for Python Doctest examples." t)
(add-to-list 'auto-mode-alist '("\\.doctest\\'" . doctest-mode))


(provide 'site-gentoo)

;; Local Variables:
;; no-byte-compile: t
;; buffer-read-only: t
;; End:

;;; site-gentoo.el ends here
